@@ -53,6 +53,7 @@ my %binary = (
     '%'  => 'mod',
 
     '~'  => 'concat',
+    'x'  => 'repeat',
 
     '+|' => 'bitor',
     '+&' => 'bitand',
@@ -127,13 +128,10 @@ has dependencies => (
     init_arg => undef,
 );
 
-has escape_mode => (
-    is  => 'rw',
-    isa => enum([qw(html none)]),
-
+has type => (
+    is      => 'rw',
+    isa     => enum([qw(html xml text)]),
     default => 'html',
-
-    init_arg => 'escape',
 );
 
 has syntax => (
@@ -233,11 +231,13 @@ sub compile {
     my $header = delete $self->{header};
     my $footer = delete $self->{footer};
 
-    if($header) {
-        substr $input, 0, 0, $self->_cat_files($header);
-    }
-    if($footer) {
-        $input .= $self->_cat_files($footer);
+    if(!$args{from_include}) {
+        if($header) {
+            substr $input, 0, 0, $self->_cat_files($header);
+        }
+        if($footer) {
+            $input .= $self->_cat_files($footer);
+        }
     }
 
     my @code; # main code
@@ -282,7 +282,7 @@ sub opcode { # build an opcode
     my $file   = $args{file};
     if(not defined $file) {
         $file = $self->filename;
-        if($file ne $self->current_file) {
+        if(defined $file and $file ne $self->current_file) {
             $self->current_file($file);
         }
         else {
@@ -564,7 +564,7 @@ sub _generate_command {
     my @code;
 
     my $proc = $node->id;
-    if($proc eq 'print' and $self->escape_mode ne 'html') {
+    if($proc eq 'print' and $self->type eq 'text') {
         $proc = 'print_raw';
     }
 
@@ -814,7 +814,8 @@ sub _generate_if {
 
     if($OPTIMIZE) {
         if($self->_code_is_literal(@cond)) {
-            if($cond[0][1]) {
+            my $value = $cond[0][1];
+            if($cond_true eq 'and' ? $value : !$value) {
                 return @then;
             }
             else {
@@ -1357,7 +1358,7 @@ __END__
 
 =head1 NAME
 
-Text::Xslate::Compiler - The Xslate compiler
+Text::Xslate::Compiler - An Xslate compiler to generate intermediate code
 
 =head1 DESCRIPTION
 
