@@ -57,7 +57,10 @@ sub html_builder (&){
     my($code_ref) = @_;
     return sub {
         my($s) = @_;
-        return mark_raw( $code_ref->(unmark_raw($s)) );
+        my $ret = $code_ref->(unmark_raw($s));
+        return ref($ret) eq 'CODE'
+            ? html_builder(\&{$ret})
+            : mark_raw($ret);
     };
 }
 
@@ -160,7 +163,10 @@ sub import_from {
 
         my $commands;
         if(ref $_[$i+1]){
-            $commands = p($_[++$i]);
+            require 'Data/Dumper.pm';
+            my @args   = ($_[++$i]);
+            my @protos = ('*data');
+            $commands = Data::Dumper->new(\@args, \@protos)->Terse(1)->Dump();
         }
 
         $code .= "use $module ();\n" if !$module->can('export_into_xslate');
@@ -254,9 +260,9 @@ sub read_around { # for error messages
     return $s;
 }
 
-sub p { # for debugging
+sub p { # for debugging, the guts of dump()
     require 'Data/Dumper.pm'; # we don't want to create its namespace
-    my $dd = Data::Dumper->new([@_ == 1 ? @_ : \@_], ['*data']);
+    my $dd = Data::Dumper->new(\@_);
     $dd->Indent(1);
     $dd->Sortkeys(1);
     $dd->Quotekeys(0);
